@@ -1,5 +1,6 @@
+import os
 import shutil
-import sys
+import stat
 from pathlib import PosixPath
 from typing import Dict, NamedTuple
 
@@ -26,6 +27,13 @@ class CloudTestServer(NamedTuple):
 cloud_server_cache: Dict[str, CloudTestServer] = {}
 
 
+# From: https://docs.python.org/3/library/shutil.html#rmtree-example
+def remove_readonly(func, path, _):
+    "Clear the readonly bit and reattempt the removal"
+    os.chmod(path, stat.S_IWRITE)
+    func(path)
+
+
 @pytest.fixture
 def cloud_test_catalog(request, tmp_path, tmp_upath_factory, data_storage):
     cloud_type = request.param
@@ -98,9 +106,6 @@ def test_find(cloud_test_catalog):
         )
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 @pytest.mark.parametrize(
     "recursive,star",
@@ -114,7 +119,7 @@ def test_cp_root(cloud_test_catalog, recursive, star):
     dest = working_dir / "data"
 
     if star:
-        src_path = str(src / "*")
+        src_path = f"{str(src).rstrip('/')}/*"
     else:
         src_path = str(src)
 
@@ -186,9 +191,6 @@ def test_cp_root(cloud_test_catalog, recursive, star):
         assert f"{prefix}dogs/others/dog4" not in files_by_name
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 @pytest.mark.parametrize(
     "recursive,star,slash",
@@ -209,7 +211,7 @@ def test_cp_subdir(cloud_test_catalog, recursive, star, slash):
     dest = working_dir / "data"
 
     if star:
-        src_path = str(src / "*")
+        src_path = f"{str(src)}/*"
     else:
         src_path = str(src)
         if slash:
@@ -280,9 +282,6 @@ def test_cp_subdir(cloud_test_catalog, recursive, star, slash):
     assert files_by_name["dogs/others/dog4"]["size"] == 4
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 @pytest.mark.parametrize(
     "recursive,star,slash",
@@ -306,7 +305,7 @@ def test_cp_multi_subdir(cloud_test_catalog, recursive, star, slash):
     dest = working_dir / "data"
 
     if star:
-        src_paths = [str(src / "*") for src in sources]
+        src_paths = [f"{str(src)}/*" for src in sources]
     else:
         src_paths = [str(src) for src in sources]
         if slash:
@@ -396,9 +395,6 @@ def test_cp_multi_subdir(cloud_test_catalog, recursive, star, slash):
     assert dog_files_by_name["dogs/others/dog4"]["size"] == 4
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 def test_cp_double_subdir(cloud_test_catalog):
     src = cloud_test_catalog.src / "dogs" / "others"
@@ -439,9 +435,6 @@ def test_cp_double_subdir(cloud_test_catalog):
     assert files_by_name["dog4"]["size"] == 4
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 def test_cp_dql_file_options(cloud_test_catalog):
     src = cloud_test_catalog.src / "dogs"
@@ -504,9 +497,6 @@ def test_cp_dql_file_options(cloud_test_catalog):
         )
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 def test_cp_dql_file_sources(cloud_test_catalog):
     sources = [
@@ -627,9 +617,6 @@ def test_cp_dql_file_sources(cloud_test_catalog):
     assert dog_files_by_name2["others/dog4"]["size"] == 4
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 def test_get(cloud_test_catalog):
     src = cloud_test_catalog.src
@@ -648,20 +635,15 @@ def test_get(cloud_test_catalog):
     assert dest.with_suffix(".dql").is_file()
 
 
-@pytest.mark.xfail(
-    sys.platform != "darwin", reason="reflink only works on Mac"
-)
 @pytest.mark.parametrize("cloud_test_catalog", ["s3", "gcs"], indirect=True)
 def test_get_subdir(cloud_test_catalog):
-    src = cloud_test_catalog.src / "dogs"
+    src = f"{str(cloud_test_catalog.src)}/dogs"
     working_dir = cloud_test_catalog.working_dir
     catalog = cloud_test_catalog.catalog
 
     dest = working_dir / "data"
 
-    catalog.get(
-        str(src), str(dest), client_config=cloud_test_catalog.client_config
-    )
+    catalog.get(src, str(dest), client_config=cloud_test_catalog.client_config)
 
     assert dest.with_suffix(".dql").is_file()
     assert (dest / "dog1").read_text() == "woof"
@@ -677,16 +659,16 @@ def test_get_subdir(cloud_test_catalog):
     with pytest.raises(RuntimeError):
         # An error should be raised if the output directory already exists
         catalog.get(
-            str(src), str(dest), client_config=cloud_test_catalog.client_config
+            src, str(dest), client_config=cloud_test_catalog.client_config
         )
 
-    shutil.rmtree(dest)
+    shutil.rmtree(dest, onerror=remove_readonly)
     assert dest.with_suffix(".dql").is_file()
 
     with pytest.raises(RuntimeError):
         # An error should also be raised if the dataset file already exists
         catalog.get(
-            str(src), str(dest), client_config=cloud_test_catalog.client_config
+            src, str(dest), client_config=cloud_test_catalog.client_config
         )
 
 
